@@ -60,13 +60,13 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ###################################################
 ### code chunk number 8: yaxis (eval = FALSE)
 ###################################################
-##   ggplot(mapping=aes(dat,labs)) + geom_quasirandom(aes(color=labs))
+##   ggplot(mapping=aes(dat,labs)) + geom_quasirandom(aes(color=labs),groupOnX=FALSE)
 
 
 ###################################################
 ### code chunk number 9: showYaxis
 ###################################################
-  ggplot(mapping=aes(dat,labs)) + geom_quasirandom(aes(color=labs))
+  ggplot(mapping=aes(dat,labs)) + geom_quasirandom(aes(color=labs),groupOnX=FALSE)
 
 
 ###################################################
@@ -87,14 +87,14 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ### code chunk number 12: dodgey (eval = FALSE)
 ###################################################
 ##   labs2<-factor(rep(1:2,each=n))
-##   ggplot(mapping=aes(dat,labs,color=labs2)) + geom_quasirandom(dodge.width=.8)
+##   ggplot(mapping=aes(dat,labs,color=labs2)) + geom_quasirandom(dodge.width=.8,groupOnX=FALSE)
 
 
 ###################################################
 ### code chunk number 13: showDodgey
 ###################################################
   labs2<-factor(rep(1:2,each=n))
-  ggplot(mapping=aes(dat,labs,color=labs2)) + geom_quasirandom(dodge.width=.8)
+  ggplot(mapping=aes(dat,labs,color=labs2)) + geom_quasirandom(dodge.width=.8,groupOnX=FALSE)
 
 
 ###################################################
@@ -186,7 +186,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
 ##     theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust=1))
 ##   p4<-ggplot(mapping=aes(labs, dat)) +
 ##     geom_quasirandom(method='frowney',alpha=.2) +
-##     ggtitle('smiley') + labs(x='') +
+##     ggtitle('frowney') + labs(x='') +
 ##     theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust=1))
 ##   p5<-ggplot(mapping=aes(labs, dat)) +
 ##     geom_quasirandom(method='tukey',alpha=.2) +
@@ -226,7 +226,7 @@ packageKeywords<-"visualization, display, one dimensional, grouped, groups, viol
     theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust=1))
   p4<-ggplot(mapping=aes(labs, dat)) +
     geom_quasirandom(method='frowney',alpha=.2) +
-    ggtitle('smiley') + labs(x='') +
+    ggtitle('frowney') + labs(x='') +
     theme(axis.text.x = element_text(angle = 45, vjust = 1, hjust=1))
   p5<-ggplot(mapping=aes(labs, dat)) +
     geom_quasirandom(method='tukey',alpha=.2) +
